@@ -1,17 +1,30 @@
 from collections import deque
 from ezcode.graph import Graph
-from typing import List
 
 
 class DirectedGraph(Graph):
-    def __init__(self, edges: List[list] = None, weights: list = None, mark: str = "*"):
-        super().__init__(is_weighted=(weights is not None), mark=mark)
+    def __init__(self, edge_weight_dict: dict = None, edges: list[list] = None, weights: list = None, mark: str = "*"):
+        if edge_weight_dict is None:
+            is_weighted = weights is not None
+        else:
+            is_weighted = False
+            for weight in edge_weight_dict.values():
+                if weight is not None:
+                    is_weighted = True
+                    break
+        super().__init__(is_weighted=is_weighted, mark=mark)
         # self.nodes = {node_id: {"i": {node_id: weight}, "o": {node_id: weight}}
-        if edges:
-            self.build_graph(edges=edges, weights=weights)
+        if edge_weight_dict or edges:
+            self.build_graph(edge_weight_dict=edge_weight_dict, edges=edges, weights=weights)
 
-    def build_graph(self, edges: List[list], weights: list = None):
-        if weights is None:
+    def build_graph(self, edge_weight_dict: dict = None, edges: list[list] = None, weights: list = None):
+        if edge_weight_dict:
+            edges, weights = list(), list()
+            for edge, weight in edge_weight_dict.items():
+                edges.append(edge)
+                if weight is not None:
+                    weights.append(weight)
+        if not weights:
             weights = [1] * len(edges)
         for (i, o), weight in zip(edges, weights):
             if i is not None and i not in self.nodes:
